@@ -609,13 +609,29 @@ class Insight_Definition:
         map_id = self.add_component("map", position)
         return map_id
 
-    def add_image(self, image_url):
+    def add_image(self, image, cta):
         position = (len(self.components))
         image_id = self.add_component("image", position)
-        self.edit_image(image_id, image_url)
+        image_url = self.upload_image(image)
+        self.edit_image(image_id, image_url, cta)
         return image_id
 
-    def edit_image(self, image_id,image_url, image_name="Image 1"):
+
+    def upload_image(self, image):
+
+        s = requests.Session()
+        s.keep_alive = False
+        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+        s.mount('https://', HTTPAdapter(max_retries=retries))
+
+        authentication_url = self._base_url_askdata+'/smartconfiguration/icons?folder = insightdefinition'
+
+        file = {'file': image}
+        headers = {"Authorization": "Bearer" + " " + self._token}
+        response = s.post(url=authentication_url, files=file, headers=headers)
+        response.raise_for_status()
+
+    def edit_image(self, image_id, image_url, cta, image_name="Image 1"):
 
         body = {
             "id":image_id,
@@ -625,7 +641,8 @@ class Insight_Definition:
             "dependsOn":[],
             "valid":True,
             "queryComponent":False,
-            "link": image_url
+            "link": cta,
+            "image": image_url
         }
 
         url = self.smart_insight_url+"/definitions/"+self.definition_id+"/images/"+image_id
